"""declare ORM models for GitHub related tables
"""

##__________________________________________________________________||
from .github_token import GitHubToken  # noqa: F401
from .github_org import GitHubOrg  # noqa: F401
from .github_user import GitHubUser  # noqa: F401
from .github_org_membership import GitHubOrgMembership  # noqa: F401

##__________________________________________________________________||
