"""add columns to product_types

Revision ID: d7cac99bbffa
Revises: cc64c8ef2115
Create Date: 2020-05-22 11:58:47.182210

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'd7cac99bbffa'
down_revision = 'cc64c8ef2115'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('product_types', sa.Column('icon', sa.Text(), nullable=True))
    op.add_column('product_types', sa.Column('indef_article', sa.Text(), nullable=True))
    op.add_column('product_types', sa.Column('plural', sa.Text(), nullable=True))
    op.add_column('product_types', sa.Column('singular', sa.Text(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('product_types', 'singular')
    op.drop_column('product_types', 'plural')
    op.drop_column('product_types', 'indef_article')
    op.drop_column('product_types', 'icon')
    # ### end Alembic commands ###
