"""add a field "time_created" to github_tokens

Revision ID: 2b15f740eed9
Revises: 936fc5b02f16
Create Date: 2021-01-04 12:03:13.963073

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '2b15f740eed9'
down_revision = '936fc5b02f16'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('github_tokens', schema=None) as batch_op:
        batch_op.add_column(sa.Column('time_created', sa.DateTime(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('github_tokens', schema=None) as batch_op:
        batch_op.drop_column('time_created')

    # ### end Alembic commands ###
