# fmt: off
from .mutation_create_product import MUTATION_CREATE_PRODUCT  # noqa: F401
from .mutation_delete_product import MUTATION_DELETE_PRODUCT  # noqa: F401
from .mutation_update_product import MUTATION_UPDATE_PRODUCT  # noqa: F401
from .mutation_create_product_relation_types import MUTATION_CREATE_PRODUCT_RELATION_TYPES  # noqa: F401
from .mutation_update_product_relation_type import MUTATION_UPDATE_PRODUCT_RELATION_TYPE  # noqa: F401
from .mutation_delete_product_relation_types import MUTATION_DELETE_PRODUCT_RELATION_TYPES  # noqa: F401
from .mutation_create_product_relation import MUTATION_CREATE_PRODUCT_RELATION  # noqa: F401
from .mutation_delete_product_relation import MUTATION_DELETE_PRODUCT_RELATION  # noqa: F401
from .mutation_create_product_type import MUTATION_CREATE_PRODUCT_TYPE  # noqa: F401
from .mutation_update_product_type import MUTATION_UPDATE_PRODUCT_TYPE  # noqa: F401
from .mutation_delete_product_type import MUTATION_DELETE_PRODUCT_TYPE  # noqa: F401
from .mutation_create_field import MUTATION_CREATE_FIELD  # noqa: F401
from .mutation_update_field import MUTATION_UPDATE_FIELD  # noqa: F401
from .mutation_delete_field import MUTATION_DELETE_FIELD  # noqa: F401
